# CT Extinct
This program uses deep learning and a Cybersecurity dataset to
make Cyber Threats Extinct by educating employees on how to
recognise a threat, and the correct steps to take once identified.

## Installation
'''pip install ctextinct'''

## How to use it?
Sign into your company account or Anonymously. Ask the cyber chatbot
cyber security related questions. Use the buttons to navigate to
different features of the application including a section to find the
latest Cyber News that day, or a Cyber Security Incident or Feedback form.

## License
(c) 2021 CT Extinct

This repository is licenced under the MIT licence.
See LICENCE for details.
